import { SchemaBuilder } from "./SchemaBuilder";
import { PostgresDriver } from "../driver/PostgresDriver";
import { ColumnMetadata } from "../metadata/ColumnMetadata";
import { ForeignKeyMetadata } from "../metadata/ForeignKeyMetadata";
import { TableMetadata } from "../metadata/TableMetadata";
import { IndexMetadata } from "../metadata/IndexMetadata";
import { DatabaseConnection } from "../driver/DatabaseConnection";
/**
 * @internal
 */
export declare class PostgresSchemaBuilder extends SchemaBuilder {
    private driver;
    private dbConnection;
    constructor(driver: PostgresDriver, dbConnection: DatabaseConnection);
    getChangedColumns(tableName: string, columns: ColumnMetadata[]): Promise<{
        columnName: string;
        hasPrimaryKey: boolean;
    }[]>;
    checkIfTableExist(tableName: string): Promise<boolean>;
    addColumnQuery(tableName: string, column: ColumnMetadata): Promise<void>;
    dropColumnQuery(tableName: string, columnName: string): Promise<void>;
    addForeignKeyQuery(foreignKey: ForeignKeyMetadata): Promise<void>;
    dropForeignKeyQuery(foreignKey: ForeignKeyMetadata): Promise<void>;
    dropForeignKeyQuery(tableName: string, foreignKeyName: string): Promise<void>;
    getTableForeignQuery(tableName: string): Promise<string[]>;
    getTableUniqueKeysQuery(tableName: string): Promise<string[]>;
    getTableIndicesQuery(tableName: string): Promise<{
        key: string;
        sequence: number;
        column: string;
    }[]>;
    getPrimaryConstraintName(tableName: string): Promise<string>;
    dropIndex(tableName: string, indexName: string, isGenerated?: boolean): Promise<void>;
    createIndex(tableName: string, index: IndexMetadata): Promise<void>;
    addUniqueKey(tableName: string, columnName: string, keyName: string): Promise<void>;
    getTableColumns(tableName: string): Promise<string[]>;
    changeColumnQuery(tableName: string, columnName: string, newColumn: ColumnMetadata, skipPrimary?: boolean): Promise<void>;
    createTableQuery(table: TableMetadata, columns: ColumnMetadata[]): Promise<void>;
    private query<T>(sql);
    private buildCreateColumnSql(column, skipPrimary);
    private normalizeType(column);
}
