import { TableMetadata } from "../metadata/TableMetadata";
import { ColumnMetadata } from "../metadata/ColumnMetadata";
import { ForeignKeyMetadata } from "../metadata/ForeignKeyMetadata";
import { SchemaBuilder } from "../schema-builder/SchemaBuilder";
import { EntityMetadataCollection } from "../metadata-args/collection/EntityMetadataCollection";
/**
 * Creates indexes based on the given metadata.
 *
 * @internal
 */
export declare class SchemaCreator {
    private schemaBuilder;
    private entityMetadatas;
    constructor(schemaBuilder: SchemaBuilder, entityMetadatas: EntityMetadataCollection);
    /**
     * Creates complete schemas for the given entity metadatas.
     */
    create(): Promise<void>;
    private dropForeignKeysForAll(metadatas);
    private createTablesForAll(metadatas);
    private updateOldColumnsForAll(metadatas);
    private dropRemovedColumnsForAll(metadatas);
    private addNewColumnsForAll(metadatas);
    private updateExistColumnsForAll(metadatas);
    private createForeignKeysForAll(metadatas);
    private updateUniqueKeysForAll(metadatas);
    private createIndicesForAll(metadatas);
    private removePrimaryKeyForAll(metadatas);
    /**
     * Drops all (old) foreign keys that exist in the table, but does not exist in the metadata.
     */
    private dropForeignKeys(table, foreignKeys);
    /**
     * Creates a new table if it does not exist.
     */
    private createNewTable(table, columns);
    /**
     * Renames (and updates) all columns that has "oldColumnName".
     */
    protected updateOldColumns(table: TableMetadata, columns: ColumnMetadata[], foreignKeys: ForeignKeyMetadata[]): Promise<void>;
    /**
     * Drops all columns exist (left old) in the table, but does not exist in the metadata.
     */
    protected dropRemovedColumns(table: TableMetadata, columns: ColumnMetadata[], foreignKeys: ForeignKeyMetadata[]): Promise<void[]>;
    /**
     * Adds columns from metadata which does not exist in the table.
     */
    private addNewColumns(table, columns);
    /**
     * Update all exist columns which metadata has changed.
     */
    protected updateExistColumns(table: TableMetadata, columns: ColumnMetadata[], foreignKeys: ForeignKeyMetadata[]): Promise<void[]>;
    /**
     * Creates foreign keys which does not exist in the table yet.
     */
    private createForeignKeys(table, foreignKeys);
    /**
     * Creates unique keys which are missing in db yet, and drops unique keys which exist in the db,
     * but does not exist in the metadata anymore.
     */
    private updateUniqueKeys(table, columns);
    /**
     * Creates indices which are missing in db yet, and drops indices which exist in the db,
     * but does not exist in the metadata anymore.
     */
    private createIndices(table, compositeIndices);
    /**
     * Removes primary key from the table (if it was before and does not exist in the metadata anymore).
     */
    private removePrimaryKey(table);
    private dropColumnForeignKeys(tableName, columnName, foreignKeys);
}
